@@ -48,7 +48,7 @@ class EventThread(QObject):
         self.context = zmq.Context()
         self.socket = self.context.socket(zmq.SUB)
         self.socket.connect("tcp://localhost:" + SOCKET)
-        self.socket.setsockopt(zmq.RCVTIMEO, 1000)  # Timeout for the recv() function
+        self.socket.setsockopt(zmq.RCVTIMEO, 10000)  # Timeout for the recv() function
 
         self.thread_stop = False
 
@@ -106,10 +106,10 @@ class EventListener(QObject):
     stage_position_changed_event = Signal(float)
 
     def __init__(self, socket, event_sockets, bridge: Bridge, thread: QThread,
-                 live_images: bool = False):
+                 send_live_images: bool = False):
         """Store passed arguments and starting time for frequency limitation of certain events."""
         super().__init__()
-        self.send_live_images = live_images
+        self.send_live_images = send_live_images
         self.loop_stop = False
         self.socket = socket
         self.event_sockets = event_sockets
@@ -137,25 +137,16 @@ class EventListener(QObject):
         print("EventServer running")
         while not self.loop_stop:
             instance = instance + 1 if instance < 100 else 0
+            eventString = "NoEvent"
             try:
                 #  Get the reply.
-
                 reply = str(self.socket.recv())
                 # topic = re.split(' ', reply)[0][2:]
 
                 # Translate the event to a shadow object
                 try:
                     message = json.loads(re.split(" ", reply)[1][0:-1])
-                    socket_num = instance % len(self.event_sockets)
-
-                    eventString = message["class"].split(r".")[-1]
-                    log.info(eventString)
-                    pre_evt = self.bridge._class_factory.create(message)
-                    evt = pre_evt(
-                        socket=self.event_sockets[socket_num],
-                        serialized_object=message,
-                        bridge=self.bridge,
-                    )
+                    evt, eventString = self.translate_message(message, instance)
                 except json.decoder.JSONDecodeError:
                     if self.blockImages:
                         return
@@ -163,16 +154,21 @@ class EventListener(QObject):
                     image_bit = str(self.socket.recv())
                     # TODO: Maybe this should also be done for other bitdepths?!
                     image_depth = np.uint16 if image_bit == "b'2'" else np.uint8
-                    image = np.frombuffer(self.socket.recv(), dtype=image_depth)
-                    print("IMAGE TYPE:", image.dtype)
-                    image_params = re.split("NewImage ", reply)[1]
-                    image_params = re.split(", ", image_params[1:-2])
-                    image_params = [int(round(float(x))) for x in image_params]
-                    py_image = PyImage(
-                        image.reshape([int(image_params[0]), int(image_params[1])]),
-                        *image_params[2:]
-                    )
-                    self.new_image_event.emit(py_image)
+                    next_message = self.socket.recv()
+                    print(next_message[:4])
+                    if str(next_message[:4]) == "b'Acqu'":  # AcquisitionEndedEvent interrupted
+                        print("Acquisition ENDED?")
+                        next_message = json.loads(re.split(" ", str(next_message))[1][0:-1])
+                        evt, eventString = self.translate_message(next_message, instance)
+                        print(eventString)
+                        image_message = self.socket.recv()
+                        print(image_message[:4])
+                        py_image = self.image_from_message(image_message, reply, image_depth)
+                        self.new_image_event.emit(py_image)
+                    else:
+                        py_image = self.image_from_message(next_message, reply, image_depth)
+                        self.new_image_event.emit(py_image)
+
                 print(eventString)
                 if "DefaultAcquisitionStartedEvent" in eventString:
                     if time.perf_counter() - self.last_acq_started > 0.2:
@@ -216,6 +212,30 @@ class EventListener(QObject):
                 # print("Server timeout", self.timeouts)
                 pass
 
+    def image_from_message(self, message, reply, image_depth):
+        image = np.frombuffer(message, dtype=image_depth)
+        image_params = re.split("NewImage ", reply)[1]
+        image_params = re.split(", ", image_params[1:-2])
+        image_params = [int(round(float(x))) for x in image_params]
+        py_image = PyImage(
+            image.reshape([int(image_params[0]), int(image_params[1])]),
+            *image_params[2:]
+        )
+        return py_image
+
+    def translate_message(self, message, instance):
+        socket_num = instance % len(self.event_sockets)
+
+        eventString = message["class"].split(r".")[-1]
+        log.info(eventString)
+        pre_evt = self.bridge._class_factory.create(message)
+        evt = pre_evt(
+            socket=self.event_sockets[socket_num],
+            serialized_object=message,
+            bridge=self.bridge,
+        )
+        return evt, eventString
+
     @Slot()
     def stop(self):
         """Thread was stopped, let's also close the socket then."""
